@@ -23,7 +23,7 @@ from aliyunsdkvcs.endpoint import endpoint_data
 class CreateCorpRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'CreateCorp')
+		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'CreateCorp','vcs')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -55,6 +55,12 @@ class CreateCorpRequest(RpcRequest):
 	def set_Description(self,Description):
 		self.add_body_params('Description', Description)
 
+	def get_IconPath(self):
+		return self.get_body_params().get('IconPath')
+
+	def set_IconPath(self,IconPath):
+		self.add_body_params('IconPath', IconPath)
+
 	def get_AppName(self):
 		return self.get_body_params().get('AppName')
 
