@@ -23,7 +23,7 @@ from aliyunsdkvcs.endpoint import endpoint_data
 class GetDeviceLiveUrlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'GetDeviceLiveUrl')
+		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'GetDeviceLiveUrl','vcs')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -31,6 +31,18 @@ class GetDeviceLiveUrlRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_OutProtocol(self):
+		return self.get_body_params().get('OutProtocol')
+
+	def set_OutProtocol(self,OutProtocol):
+		self.add_body_params('OutProtocol', OutProtocol)
+
+	def get_StreamType(self):
+		return self.get_body_params().get('StreamType')
+
+	def set_StreamType(self,StreamType):
+		self.add_body_params('StreamType', StreamType)
+
 	def get_CorpId(self):
 		return self.get_body_params().get('CorpId')
 
@@ -41,4 +53,10 @@ class GetDeviceLiveUrlRequest(RpcRequest):
 		return self.get_body_params().get('GbId')
 
 	def set_GbId(self,GbId):
-		self.add_body_params('GbId', GbId)
\ No newline at end of file
+		self.add_body_params('GbId', GbId)
+
+	def get_DeviceId(self):
+		return self.get_body_params().get('DeviceId')
+
+	def set_DeviceId(self,DeviceId):
+		self.add_body_params('DeviceId', DeviceId)
\ No newline at end of file
