@@ -23,7 +23,7 @@ from aliyunsdkvcs.endpoint import endpoint_data
 class ListCorpsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'ListCorps')
+		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'ListCorps','vcs')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -41,4 +41,10 @@ class ListCorpsRequest(RpcRequest):
 		return self.get_body_params().get('PageSize')
 
 	def set_PageSize(self,PageSize):
-		self.add_body_params('PageSize', PageSize)
\ No newline at end of file
+		self.add_body_params('PageSize', PageSize)
+
+	def get_CorpName(self):
+		return self.get_body_params().get('CorpName')
+
+	def set_CorpName(self,CorpName):
+		self.add_body_params('CorpName', CorpName)
\ No newline at end of file
