@@ -23,7 +23,7 @@ from aliyunsdkvcs.endpoint import endpoint_data
 class ReportDeviceCapacityRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'ReportDeviceCapacity')
+		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'ReportDeviceCapacity','vcs')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -32,7 +32,7 @@ class ReportDeviceCapacityRequest(RpcRequest):
 
 
 	def get_StreamCapacitiess(self):
-		return self.get_body_params().get('StreamCapacitiess')
+		return self.get_body_params().get('StreamCapacities')
 
 	def set_StreamCapacitiess(self, StreamCapacitiess):
 		for depth1 in range(len(StreamCapacitiess)):
